==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/ToolChain/scripts/createPackage.sh <==
#!/bin/bash

Version="$1"
if [ "$2" == "b" ]; then
  Beta="b"
fi
FullVersion=${Version}${Beta}
if [ "$Version" == "" ]; then
  echo "$0 VERSION [b]"
  echo "    VERSION version number to append (x.x.xx e.g.: 1.0.35)"
  echo "    b  a beta release automatically overwrites existing beta release of same version"
  exit 5
fi
Archive="ToolChain_STM32_${FullVersion}.tar.bz"
if  [ "$Beta" == "" ]; then
  if [ -e ../archive/$Archive ]; then
    echo "$0 ERROR: ../archive/$Archive already exists!"
    exit 6
  fi
fi

if [ ! -d ToolChain_STM32 ]; then
  git clone gitosis@hlb-labor.de:ToolChain_STM32
fi
cd ToolChain_STM32
echo $FullVersion >Version
echo $FullVersion >ToolChain/scripts/Version

mv readme.History readme.History_old
echo "$FullVersion @`date`" >readme.History
git fetch
git log HEAD..origin >>readme.History
echo "---------------------------------------------------------"  >>readme.History
echo "" >>readme.History
cat readme.History_old >>readme.History
rm readme.History_old
cp readme.* ../../

git pull
git commit -a -m "Package v${FullVersion}"
git tag -f "Package_v${FullVersion}"
git push --tags
git push
cd ..

if [ "$Beta" == "" ]; then
  rm -f ../ToolChain_STM32_current.tar.bz
else
  rm -f ../ToolChain_STM32_current_beta.tar.bz
fi

mv ToolChain_STM32/.git .
mv ToolChain_STM32 ToolChain_STM32_${FullVersion}
ln -s ToolChain_STM32_${FullVersion} ToolChain_STM32
tar cjf ../archive/ToolChain_STM32_${FullVersion}.tar.bz ToolChain_STM32_${FullVersion} ToolChain_STM32
rm ToolChain_STM32
mv ToolChain_STM32_${FullVersion} ToolChain_STM32
mv .git ToolChain_STM32/

if [ "$Beta" == "" ]; then
  ln -s archive/ToolChain_STM32_${FullVersion}.tar.bz ../ToolChain_STM32_current.tar.bz
else
  ln -s archive/ToolChain_STM32_${FullVersion}.tar.bz ../ToolChain_STM32_current_beta.tar.bz
fi

==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/scripts/createPackage.sh <==
#!/bin/bash

Version="$1"
if [ "$2" == "b" ]; then
  Beta="b"
fi
if [ "$2" == "a" ]; then
  Beta="a"
fi
FullVersion=${Version}${Beta}
if [ "$Version" == "" ]; then
  echo "$0 VERSION [a|b]"
  echo "    VERSION version number to append (x.x.xx e.g.: 1.0.35)"
  echo "    a  an alpha release automatically overwrites existing alpha release of same version"
  echo "    b  a beta release automatically overwrites existing beta release of same version"
  exit 5
fi
Archive="ToolChain_STM32_${FullVersion}.tar.bz"
if  [ "$Beta" == "" ]; then
  if [ -e ../archive/$Archive ]; then
    echo "$0 ERROR: ../archive/$Archive already exists!"
    exit 6
  fi
fi

if [ ! -d ToolChain_STM32 ]; then
  git clone gitosis@hlb-labor.de:ToolChain_STM32
fi
cd ToolChain_STM32

mv readme.History readme.History_old
echo "$FullVersion @`date`" >readme.History
git fetch
git log HEAD..origin >>readme.History
echo "---------------------------------------------------------"  >>readme.History
echo "" >>readme.History
cat readme.History_old >>readme.History
rm readme.History_old
cp readme.* ../../

git pull
echo $FullVersion >Version
echo $FullVersion >ToolChain/scripts/Version

git commit -a -m "Package v${FullVersion}"
git tag -f "Package_v${FullVersion}"
git push --tags
git push
cd ..

if [ "$Beta" == "" ]; then
   Archive="../ToolChain_STM32_current.tar.bz"
else
  if [ "$Beta" == "b" ]; then
    Archie="../ToolChain_STM32_current_beta.tar.bz"
  else
    Archie="../ToolChain_STM32_current_alpha.tar.bz"
  fi
fi
rm -f $Archive

mv ToolChain_STM32/.git .
mv ToolChain_STM32 ToolChain_STM32_${FullVersion}
ln -s ToolChain_STM32_${FullVersion} ToolChain_STM32
tar cjf ../archive/ToolChain_STM32_${FullVersion}.tar.bz ToolChain_STM32_${FullVersion} ToolChain_STM32
rm ToolChain_STM32
mv ToolChain_STM32_${FullVersion} ToolChain_STM32
mv .git ToolChain_STM32/

ln -sv archive/ToolChain_STM32_${FullVersion}.tar.bz $Archive
